==> RHMS_1.0.tar.gz: RHMS/man/createReservoir.default.Rd <==
\name{createReservoir.default}
\alias{createReservoir.default}
\title{
creates a reservoir object
}
\description{
creates a reservoir object, supporting direct inflow
}
\usage{
\method{createReservoir}{default}(name = "Unttitled", inflow = NA, ratingCurve,
                                  dischargeCurve, initialStorage, capacity,
                                  delayInflow = 1, label, downstream = NA)
}
\arguments{
  \item{name}{
a string: the name of reservoir to be instantiated
}
  \item{inflow}{
a vector (optional): a time series of direct inflow rather than flows comming from upstream
}
  \item{ratingCurve}{
a data frame: a data frame at which its first collumn includes height (masl)
and second collums presents equivalant volume to the height at first collumn (MCM)
}
  \item{dischargeCurve}{
a data frame: a data frame at which its first collumn includes height (masl)
and second collums presents equivalant discharge rate to the height at first collumn (cms)
}
  \item{initialStorage}{
the initial storage of reservoir at the first time step of simulation (MCM)
}
  \item{capacity}{
the maximum volume of reservoir capacity (MCM)
}
  \item{delayInflow}{
an integer: presenting the time steps ro delay direct inflow time series
}
  \item{label}{
an integer: a unique number known as code label
}
  \item{downstream}{
an integer: the downstream object code
}
}
\value{
a list: an object from class of createReservoir
}
\seealso{ \code{\link[RHMS]{addObjectToBasin}} }
\author{
Rezgar Arabzadeh
}
\keyword{ list }

==> RHMS_1.1.tar.gz: RHMS/man/createReservoir.default.Rd <==
\name{createReservoir.default}
\alias{createReservoir.default}
\title{
default function for class of \emph{createReservoir}
}
\description{
instantiates an object from class of \emph{createReservoir}
}
\usage{
\method{createReservoir}{default}(name = "Unttitled", inflow = NA, ratingCurve,
                                  dischargeCurve, initialStorage, capacity,
                                  delayInflow = 1, label, downstream = NA)
}
\arguments{
  \item{name}{
a string: the name of reservoir to be instantiated
}
  \item{inflow}{
a vector (optional): a time series of direct inflow rather than flows comming from upstream (cms)
}
  \item{ratingCurve}{
a data frame: a data frame at which its first collumn includes height (masl)
and second collums presents equivalant volume to the height at first collumn (MCM)
}
  \item{dischargeCurve}{
a data frame: a data frame at which its first collumn includes height (masl)
and second collums presents equivalant discharge rate to the height at first collumn (cms)
}
  \item{initialStorage}{
the initial storage of reservoir at the first time step of simulation (MCM)
}
  \item{capacity}{
the maximum volume of reservoir capacity (MCM)
}
  \item{delayInflow}{
an integer (optional): presenting the time steps to delay direct inflow time series
}
  \item{label}{
an integer: a unique number, as label
}
  \item{downstream}{
an integer: the code of downstream object 
}
}
\value{
a list: an object from class of \emph{createReservoir}
}
\seealso{ \code{\link[RHMS]{addObjectToBasin}} }
\author{
Rezgar Arabzadeh
}
\keyword{ list }
